/*
 * SPDX-License-Identifier: Apache-2.0
 *
 *
 */

 #include <zephyr/types.h>
 #include <stddef.h>
 #include <string.h>
 #include <zephyr/kernel.h>
 #include <zephyr/sys/printk.h>
 #include <zephyr/bluetooth/bluetooth.h>
 #include <zephyr/bluetooth/hci.h>
 
 
 static bool manuf_data_print(struct bt_data *data, void *user_data)
 {
	 if (data->type == BT_DATA_MANUFACTURER_DATA) {
	
		 printk("Manufacturer Data (len %u): ", data->data_len);
		 for (uint8_t i = 0; i < data->data_len; i++) {
			 printk("%02X ", data->data[i]);
		 }
		 printk("\n");
	 }
 
	 return true;
 }
 
 static bool parse_name_cb(struct bt_data *data, void *user_data)
 {
	 char *dev_name = user_data;
 
	 if (data->type == BT_DATA_NAME_COMPLETE || data->type == BT_DATA_NAME_SHORTENED) {
		 memcpy(dev_name, data->data, data->data_len);
		 dev_name[data->data_len] = '\0';
		 return false;
	 }
	 return true;
 }
 
 static void scan_recv_cb(const bt_addr_le_t *addr, int8_t rssi,
	uint8_t adv_type, struct net_buf_simple *buf) 
{
char addr_str[BT_ADDR_LE_STR_LEN];
char dev_name[31] = {0};


uint8_t backup_buf[buf->len];
memcpy(backup_buf, buf->data, buf->len);


struct net_buf_simple backup;
net_buf_simple_init_with_data(&backup, backup_buf, buf->len);


bt_data_parse(buf, parse_name_cb, dev_name); 


if (strcmp(dev_name, "TX beacon") == 0) {printk("Target device found!\n");
// // bt_addr_le_to_str(addr, addr_str, sizeof(addr_str));
// // printk("Target device found: %s (RSSI %d)\n", addr_str, rssi);



bt_data_parse(&backup, manuf_data_print, NULL);}

}

 int main(void)
 {
	 int err;
 
	 printk("BLE Scanner started\n");
 

	 err = bt_enable(NULL);
	 if (err) {
		 printk("Bluetooth init failed (err %d)\n", err);
		 return err;
	 }
	 printk("Bluetooth initialized\n");
 

	 struct bt_le_scan_param scan_param = {
		 .type     = BT_LE_SCAN_TYPE_ACTIVE,
		 .options  = BT_LE_SCAN_OPT_NONE,
		 .interval = 0x0060,  /* 扫描间隔：60 * 0.625 = 37.5ms */
		 .window   = 0x0030,  /* 扫描窗口：约18.75ms */
	 };
 

	 err = bt_le_scan_start(&scan_param, scan_recv_cb);
	 if (err) {
		 printk("Starting scanning failed (err %d)\n", err);
		 return err;
	 }
	 printk("Scanning successfully started\n");
 
	 while (1) {
		 k_sleep(K_SECONDS(1));
	 }
 
	 return 0;
 }
 